@@ -1,8 +1,8 @@
 """Use heuristics to guess if it is a text file or a binary file."""
-
 from __future__ import unicode_literals
 
-from dvc.utils.compat import is_py3, open
+from dvc.utils.compat import is_py3
+from dvc.utils.compat import open
 
 # Based on https://eli.thegreenplace.net/2011/10/19/
 # perls-guess-if-file-is-text-or-binary-implemented-in-python
