@@ -1,17 +1,23 @@
 """Manages state database used for checksum caching."""
-
 from __future__ import unicode_literals
 
+import logging
 import os
 import re
 import sqlite3
-import logging
 
 from dvc.config import Config
-from dvc.utils import remove, current_timestamp, relpath, to_chunks
 from dvc.exceptions import DvcException
-from dvc.utils.fs import get_mtime_and_size, get_inode
-from dvc.utils.compat import fspath_py35, urlencode, urlunparse, is_py2
+from dvc.utils import current_timestamp
+from dvc.utils import relpath
+from dvc.utils import remove
+from dvc.utils import to_chunks
+from dvc.utils.compat import fspath_py35
+from dvc.utils.compat import is_py2
+from dvc.utils.compat import urlencode
+from dvc.utils.compat import urlunparse
+from dvc.utils.fs import get_inode
+from dvc.utils.fs import get_mtime_and_size
 
 
 SQLITE_MAX_VARIABLES_NUMBER = 999
